OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Pisanje u direktorij „config” nije moguće!",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Međutim, ako želite da datoteka config.php ostane samo za čitanje, postavite opciju „config_is_read_only” na „true”.",
    "See %s" : "Pogledajte %s",
    "Sample configuration detected" : "Pronađena ogledna konfiguracija",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Otkriveno je kopiranje ogledne konfiguracije. To može dovesti do poteškoća u radu vaše instalacije i nije podržano. Pročitajte dokumentaciju prije nego što izvršite promjene u config.php",
    "%s email verification" : "Provjeru e-pošte %s",
    "Email verification" : "Provjera e-pošte",
    "Click the following button to confirm your email." : "Kliknite sljedeći gumb kako biste potvrdili svoju e-poštu.",
    "Click the following link to confirm your email." : "Kliknite na sljedeću poveznicu kako biste potvrdili svoju e-poštu.",
    "Confirm your email" : "Potvrdite svoju zaporku",
    "Other activities" : "Druge aktivnosti",
    "%1$s and %2$s" : "%1$s i %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s i %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
    "Education Edition" : "Obrazovno izdanje",
    "Enterprise bundle" : "Enterprise paket",
    "Groupware bundle" : "Paket grupnog softvera",
    "Hub bundle" : "Paket alata",
    "Social sharing bundle" : "Paket dijeljenja na društvenim mrežama",
    "PHP %s or higher is required." : "PHP inačica treba biti %s ili viša.",
    "PHP with a version lower than %s is required." : "Potreban je PHP inačice manje od %s.",
    "%sbit or higher PHP required." : "Potreban je %s-bitni ili viši PHP.",
    "The following architectures are supported: %s" : "Podržane su sljedeće arhitekture: %s",
    "The following databases are supported: %s" : "Podržane su sljedeće baze podataka: %s",
    "The command line tool %s could not be found" : "Alat naredbenog retka %s nije pronađen",
    "The library %s is not available." : "Biblioteka %s nije dostupna.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Potrebna je biblioteka %1$s inačice veće od %2$s – dostupna je inačica %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Potrebna je biblioteka %1$s inačice manje od %2$s – dostupna je inačica %3$s.",
    "The following platforms are supported: %s" : "Podržane su sljedeće platforme: %s",
    "Server version %s or higher is required." : "Inačica poslužitelja treba biti %s ili viša.",
    "Server version %s or lower is required." : "Potrebna je inačica poslužitelja %s ili niža.",
    "Wiping of device %s has started" : "Počelo je brisanje sadržaja s uređaja %s",
    "Wiping of device »%s« has started" : "Počelo je brisanje sadržaja s uređaja »%s«",
    "»%s« started remote wipe" : "»%s« je počeo daljinsko brisanje",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Uređaj ili aplikacija »%s« započela je postupak daljinskog brisanja. Primit ćete još jednu poruku e-pošte nakon završetka postupka",
    "Wiping of device %s has finished" : "Završilo je brisanje sadržaja s uređaja %s",
    "Wiping of device »%s« has finished" : "Završilo je brisanje sadržaja s uređaja »%s«",
    "»%s« finished remote wipe" : "»%s« je završio daljinsko brisanje",
    "Device or application »%s« has finished the remote wipe process." : "Uređaj ili aplikacija »%s« završila je postupak daljinskog brisanja.",
    "Remote wipe started" : "Pokrenuto je udaljeno brisanje",
    "A remote wipe was started on device %s" : "Pokrenuto je udaljeno brisanje na uređaju %s",
    "Remote wipe finished" : "Udaljeno brisanje je završeno",
    "The remote wipe on %s has finished" : "Udaljeno brisanje %s je završeno",
    "Authentication" : "Autentifikacija",
    "Unknown filetype" : "Vrsta datoteke nepoznata",
    "Invalid image" : "Slika neispravna",
    "Avatar image is not square" : "Slika avatara nije kvadratna",
    "Files" : "Datoteke",
    "View profile" : "Prikaži profil",
    "today" : "danas",
    "tomorrow" : "sutra",
    "yesterday" : "jučer",
    "_in %n day_::_in %n days_" : ["za %n dan","za %n dana","za %n dana"],
    "_%n day ago_::_%n days ago_" : ["Prije %n dana","Prije %n dana","Prije %n dana"],
    "next month" : "sljedeći mjesec",
    "last month" : "prošli mjesec",
    "_in %n month_::_in %n months_" : ["za %n mjesec","za %n mjeseci","za %n mjeseci"],
    "_%n month ago_::_%n months ago_" : ["prije %n mjeseci","prije %n mjeseci","prije %n mjeseci"],
    "next year" : "sljedeće godine",
    "last year" : "prošle godine",
    "_in %n year_::_in %n years_" : ["za %n godinu","za %n godina","za %n godina"],
    "_%n year ago_::_%n years ago_" : ["Prije %n godine","Prije %n godina","Prije %n godina"],
    "_in %n hour_::_in %n hours_" : ["za %n sat","za %n sati","za %n sati"],
    "_%n hour ago_::_%n hours ago_" : ["Prije %n sata","Prije %n sati","Prije %n sati"],
    "_in %n minute_::_in %n minutes_" : ["za %n minutu","za %n minuta","za %n minuta"],
    "_%n minute ago_::_%n minutes ago_" : ["Prije %n minute","Prije %n minuta","Prije %n minuta"],
    "in a few seconds" : "za nekoliko sekundi",
    "seconds ago" : "prije nekoliko sekundi",
    "Empty file" : "Prazna datoteka",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s ID-om: %s ne postoji. Omogućite ga u postavkama svojih aplikacija ili se obratite administratoru.",
    "File already exists" : "Datoteka već postoji",
    "Invalid path" : "Nevažeći put",
    "Failed to create file from template" : "Stvaranje datoteke iz predloška nije uspjelo",
    "Templates" : "Predlošci",
    "File name is a reserved word" : "Naziv datoteke je rezervirana riječ",
    "File name contains at least one invalid character" : "Naziv datoteke sadrži barem jedan nevažeći znak",
    "File name is too long" : "Naziv datoteke je predugačak",
    "Dot files are not allowed" : "Datoteke s točkama nisu dopuštene",
    "Empty filename is not allowed" : "Datoteke bez naziva nisu dopuštene",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikaciju „%s” nije moguće instalirati jer se ne može pročitati datoteka s podacima o aplikaciji.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikaciju „%s” nije moguće instalirati jer nije kompatibilna s ovom inačicom poslužitelja.",
    "__language_name__" : "Hrvatski",
    "This is an automatically sent email, please do not reply." : "Ovo je automatski poslana poruka e-pošte, nemojte odgovarati.",
    "Help" : "Pomoć",
    "Apps" : "Aplikacije",
    "Settings" : "Postavke",
    "Log out" : "Odjava",
    "Users" : "Korisnici",
    "Email" : "E-pošta",
    "Mail %s" : "Pošta %s",
    "Phone" : "Telefon",
    "Call %s" : "Poziv %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Prikaži %s na Twitteru",
    "Website" : "Web-mjesto",
    "Visit %s" : "Posjeti %s",
    "Address" : "Adresa",
    "Profile picture" : "Profilna slika",
    "About" : "Informacije",
    "Headline" : "Naslov",
    "Organisation" : "Organizacija",
    "Role" : "Uloga",
    "Additional settings" : "Dodatne postavke",
    "You need to enter details of an existing account." : "Trebate unijeti informacije o postojećem računu.",
    "Oracle connection could not be established" : "Nije moguće uspostaviti vezu s bazom podataka Oracle",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s na ovoj platformi neće raditi kako treba. Koristite na vlastiti rizik!",
    "For the best results, please consider using a GNU/Linux server instead." : "Za najbolje rezultate razmotrite mogućnost korištenja poslužitelja GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Čini se da se ova %s instanca izvodi u 32-bitnom PHP okruženju, a open_basedir je konfiguriran u php.ini. To će dovesti do problema s datotekama većim od 4 GB i stoga se ne preporučuje.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Uklonite postavku open_basedir iz datoteke php.ini ili se prebacite na 64-bitni PHP.",
    "Set an admin password." : "Postavite zaporku administratora.",
    "Cannot create or write into the data directory %s" : "Nije moguće stvoriti ili pisati u direktorij s podacima %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Pozadina za dijeljenje %s mora implementirati sučelje OCP\\Share_Backend",
    "Sharing backend %s not found" : "Pozadina za dijeljenje %s nije pronađena",
    "Sharing backend for %s not found" : "Pozadina za dijeljenje za %s nije pronađena",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s dijeli »%2$s« s vama i želi dodati:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s dijeli »%2$s« s vama i želi dodati",
    "»%s« added a note to a file shared with you" : "»%s« je dodao bilješku datoteci koju dijeli s vama",
    "Open »%s«" : "Otvori »%s«",
    "%1$s via %2$s" : "%1$s putem %2$s",
    "You are not allowed to share %s" : "Nije vam dopušteno dijeliti %s",
    "Cannot increase permissions of %s" : "Nije moguće povećati dopuštenja za %s",
    "Files cannot be shared with delete permissions" : "Datoteke se ne mogu dijeliti s dopuštenjima za brisanje",
    "Files cannot be shared with create permissions" : "Datoteke se ne mogu dijeliti s dopuštenjima za stvaranje",
    "Expiration date is in the past" : "Datum isteka je u prošlosti",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ne može se postaviti datum isteka više od %n dan u budućnosti","Ne može se postaviti datum isteka više od %n dana u budućnosti","Ne može se postaviti datum isteka više od %n dana u budućnosti"],
    "Sharing is only allowed with group members" : "Dijeljenje je dopušteno samo članovima grupe",
    "%1$s shared »%2$s« with you" : "%1$s dijeli »%2$s« s vama",
    "%1$s shared »%2$s« with you." : "%1$s dijeli »%2$s« s vama.",
    "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
    "The requested share does not exist anymore" : "Zatraženo dijeljenje više ne postoji",
    "Could not find category \"%s\"" : "Kategorija „%s” nije pronađena",
    "Sunday" : "Nedjelja",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sun." : "Ned.",
    "Mon." : "Pon.",
    "Tue." : "Uto.",
    "Wed." : "Sri.",
    "Thu." : "Čet.",
    "Fri." : "Pet.",
    "Sat." : "Sub.",
    "Su" : "Ne.",
    "Mo" : "Po.",
    "Tu" : "Ut.",
    "We" : "Sr.",
    "Th" : "Če.",
    "Fr" : "Pe.",
    "Sa" : "Su.",
    "January" : "Siječanj",
    "February" : "Veljača",
    "March" : "Ožujak",
    "April" : "Travanj",
    "May" : "Svibanj",
    "June" : "Lipanj",
    "July" : "Srpanj",
    "August" : "Kolovoz",
    "September" : "Rujan",
    "October" : "Listopad",
    "November" : "Studeni",
    "December" : "Prosinac",
    "Jan." : "Sij.",
    "Feb." : "Velj.",
    "Mar." : "Ožu.",
    "Apr." : "Tra.",
    "May." : "Svi.",
    "Jun." : "Lip.",
    "Jul." : "Srp.",
    "Aug." : "Kol.",
    "Sep." : "Ruj.",
    "Oct." : "Lis.",
    "Nov." : "Stu.",
    "Dec." : "Pro.",
    "A valid password must be provided" : "Nužno je navesti ispravnu zaporku",
    "Login canceled by app" : "Prijava je otkazana putem aplikacije",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikaciju „%1$s” nije moguće instalirati jer nisu ispunjene sljedeće ovisnosti: %2$s",
    "a safe home for all your data" : "siguran dom za sve vaše podatke",
    "File is currently busy, please try again later" : "Datoteka je trenutno zauzeta, pokušajte ponovo kasnije",
    "Application is not enabled" : "Aplikacija nije omogućena",
    "Authentication error" : "Pogrešna autentifikacija",
    "Token expired. Please reload page." : "Token je istekao. Ponovno učitajte stranicu.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nisu instalirani upravljački programi baze podataka (sqlite, mysql ili postgresql).",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ako želite da datoteku config.php ostane samo za čitanje, postavite opciju „config_is_read_only” na „true”. Pogledajte %s",
    "PHP module %s not installed." : "PHP modul %s nije instaliran.",
    "Please ask your server administrator to install the module." : "Zamolite svog administratora poslužitelja da instalira modul.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP postavka „%s” nije postavljena na „%s”.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Podešavanjem ove postavke u php.ini možete ponovno pokrenuti Nextcloud",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je očigledno postavljen za uklanjanje inline doc blokova. Zbog toga će nekoliko osnovnih aplikacija biti nedostupne.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemoriranja kao što je Zend OPcache ili eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduli su instalirani, ali još uvijek su na popisu onih koji nedostaju?",
    "Please ask your server administrator to restart the web server." : "Molimo zamolite svog administratora poslužitelja da ponovno pokrene web poslužitelj.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Provjerite postoji li datoteka pod nazivom „.ocdata” u korijenu podatkovnog direktorija.",
    "Action \"%s\" not supported or implemented." : "Radnja „%s” nije podržana ili provedena.",
    "Authentication failed, wrong token or provider ID given" : "Autentifikacija nije uspjela, dan je pogrešan token ili ID davatelja usluge",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Nedostaju parametri za ispunjavanje zahtjeva. Nedostaju parametri: „%s”",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID „%1$s” već koristi davatelj usluga udruženog oblaka „%2$s”",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Davatelj usluga udruženog oblaka s ID-om: „%s” ne postoji.",
    "Could not obtain lock type %d on \"%s\"." : "Nije moguće dobiti vrstu zaključavanja %d na „%s”.",
    "Storage unauthorized. %s" : "Neovlaštena pohrana. %s",
    "Storage incomplete configuration. %s" : "Nepotpuna konfiguracija pohrane. %s",
    "Storage connection error. %s" : "Pogreška veze pohrane. %s",
    "Storage is temporarily not available" : "Pohrana privremeno nije dostupna",
    "Storage connection timeout. %s" : "Istek veze pohrane. %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Datoteke aplikacije %1$s nisu ispravno zamijenjene. Provjerite je li inačica kompatibilna s poslužiteljem.",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prijavljeni korisnik mora biti administrator, podadministrator ili imati posebna prava za pristupanje ovoj postavci",
    "Logged in user must be an admin or sub admin" : "Prijavljeni korisnik mora biti administrator ili podadministrator",
    "Logged in user must be an admin" : "Korisnik koji je prijavljen mora biti administrator",
    "Full name" : "Puno ime",
    "Unknown user" : "Nepoznat korisnik",
    "MySQL username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka MySQL",
    "Oracle username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka Oracle",
    "PostgreSQL username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka PostgreSQL",
    "Set an admin username." : "Postavite korisničko ime administratora.",
    "Sharing %s failed, because this item is already shared with user %s" : "Dijeljenje %s nije uspjelo jer je ova stavka već podijeljena s korisnikom %s",
    "The username is already being used" : "Korisničko ime se već koristi",
    "Could not create user" : "Nije moguće stvoriti korisnika",
    "A valid username must be provided" : "Nužno je navesti ispravno korisničko ime",
    "Username contains whitespace at the beginning or at the end" : "Korisničko ime sadrži bijeli prostor na početku ili na kraju",
    "Username must not consist of dots only" : "Korisničko ime ne smije se sastojati samo od točkica",
    "Username is invalid because files already exist for this user" : "Korisničko ime je nevažeće jer već postoje datoteke za ovog korisnika",
    "User disabled" : "Korisnik je onemogućen",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Potreban je barem Libxml2 2.7.0. Trenutno je instalirana inačica %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Kako biste riješili ovaj problem, ažurirajte svoju inačicu libxml2 i ponovno pokrenite web poslužitelj.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Promijenite dozvole na 0770 tako da se tim direktorijem ne mogu služiti drugi korisnici."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
